@@ -26,6 +26,7 @@ function DefaultNavigation(widget) {
     this.panning = false;
     this.savedCursor = undefined;
     this.panOrigin = new RVector();
+    this.panFirstOrigin = new RVector();
     if (!isNull(widget)) {
         this.hruler = widget.findChild("HorizontalRuler");
         this.vruler = widget.findChild("VerticalRuler");
@@ -57,6 +58,8 @@ DefaultNavigation.applyPreferences = function(doc) {
     DefaultNavigation.reverseMouseWheelZoom = RSettings.getBoolValue("GraphicsViewNavigation/ReverseMouseWheelZoom", false);
     DefaultNavigation.mouseWheelZoomFactor = RSettings.getDoubleValue("GraphicsViewNavigation/MouseWheelZoomFactor", 1.2);
     DefaultNavigation.panGesture = RSettings.getBoolValue("GraphicsViewNavigation/PanGesture", false);
+    DefaultNavigation.middleMouseButtonZoomFactor = RSettings.getDoubleValue("GraphicsViewNavigation/MiddleMouseButtonZoomFactor", 1.2);
+    DefaultNavigation.panThreshold = RSettings.getDoubleValue("GraphicsViewNavigation/PanThreshold", 4);
 };
 
 DefaultNavigation.prototype.beginEvent = function() {
@@ -107,9 +110,9 @@ DefaultNavigation.prototype.mousePressEvent = function(event) {
          event.modifiers().valueOf() === Qt.ControlModifier.valueOf())) {
 
         this.panOrigin = event.getScreenPosition();
+        this.panFirstOrigin = this.panOrigin;
         this.panning = true;
         this.savedCursor = this.view.getCursor();
-        this.view.setCursor(new QCursor(Qt.OpenHandCursor));
         this.view.startPan();
         EAction.disableCoordinateWidget();
     }
@@ -124,6 +127,17 @@ DefaultNavigation.prototype.mouseReleaseEvent = function(event) {
         (event.button() === Qt.MidButton ||
          event.button() === Qt.LeftButton)) {
 
+        if (this.panFirstOrigin.getDistanceTo(event.getScreenPosition())<DefaultNavigation.panThreshold) {
+            // zoom in / out:
+            var position = event.getModelPosition();
+            if (event.modifiers().valueOf() === Qt.ShiftModifier.valueOf()) {
+                this.view.zoomOut(position, DefaultNavigation.middleMouseButtonZoomFactor);
+            }
+            else {
+                this.view.zoomIn(position, DefaultNavigation.middleMouseButtonZoomFactor);
+            }
+        }
+
         if (!isNull(this.savedCursor)) {
             this.view.setCursor(this.savedCursor);
         }
@@ -145,7 +159,7 @@ DefaultNavigation.prototype.mouseMoveEvent = function(event) {
         if (this.panning === true) {
             var panTarget = event.getScreenPosition();
             var panDelta = panTarget.operator_subtract(this.panOrigin);
-            if (Math.abs(panDelta.x) > 2 || Math.abs(panDelta.y) > 2) {
+            if (Math.abs(panDelta.x) > DefaultNavigation.panThreshold || Math.abs(panDelta.y) > DefaultNavigation.panThreshold) {
                 this.view.setCursor(
                     new QCursor(Qt.ClosedHandCursor)
                 );
